@@ -32,23 +32,24 @@ func NewOutput(ctx context.Context, g *netmap.Graph, e *enum.Enumeration, filter
 	}
 
 	var assets []*types.Asset
+	qtime := e.Config.CollectionStartTime.UTC()
 	for _, atype := range []oam.AssetType{oam.FQDN, oam.IPAddress, oam.Netblock, oam.ASN, oam.RIROrg} {
-		if a, err := g.DB.FindByType(atype, e.Config.CollectionStartTime.UTC()); err == nil {
+		if a, err := g.DB.FindByType(atype, qtime); err == nil {
 			assets = append(assets, a...)
 		}
 	}
 
 	for _, from := range assets {
-		fromstr := extractAssetName(from, e.Config.CollectionStartTime.UTC())
+		fromstr := extractAssetName(from, qtime)
 
-		if rels, err := g.DB.OutgoingRelations(from, e.Config.CollectionStartTime.UTC()); err == nil {
+		if rels, err := g.DB.OutgoingRelations(from, qtime); err == nil {
 			for _, rel := range rels {
 				lineid := from.ID + rel.ID + rel.ToAsset.ID
 				if filter.Has(lineid) {
 					continue
 				}
-				if to, err := g.DB.FindById(rel.ToAsset.ID, e.Config.CollectionStartTime.UTC()); err == nil {
-					tostr := extractAssetName(to, e.Config.CollectionStartTime.UTC())
+				if to, err := g.DB.FindById(rel.ToAsset.ID, qtime); err == nil {
+					tostr := extractAssetName(to, qtime)
 
 					output = append(output, fmt.Sprintf("%s %s %s %s %s", fromstr, "-->", magenta(rel.Type), "-->", tostr))
 					filter.Insert(lineid)
@@ -92,9 +93,9 @@ func extractAssetName(a *types.Asset, since time.Time) string {
 // ExtractOutput is a convenience method for obtaining new discoveries made by the enumeration process.
 func ExtractOutput(ctx context.Context, g *netmap.Graph, e *enum.Enumeration, filter *stringset.Set, asinfo bool) []*requests.Output {
 	if e.Config.Passive {
-		return EventNames(ctx, g, e.Config.Domains(), e.Config.CollectionStartTime.UTC(), filter)
+		return EventNames(ctx, g, e.Config.Domains(), e.Config.CollectionStartTime, filter)
 	}
-	return EventOutput(ctx, g, e.Config.Domains(), e.Config.CollectionStartTime.UTC(), filter, asinfo, e.Sys.Cache())
+	return EventOutput(ctx, g, e.Config.Domains(), e.Config.CollectionStartTime, filter, asinfo, e.Sys.Cache())
 }
 
 type outLookup map[string]*requests.Output
@@ -118,7 +119,12 @@ func EventOutput(ctx context.Context, g *netmap.Graph, domains []string, since t
 		fqdns = append(fqdns, domain.FQDN{Name: d})
 	}
 
-	assets, err := g.DB.FindByScope(fqdns, since)
+	qtime := time.Time{}
+	if !since.IsZero() {
+		qtime = since.UTC()
+	}
+
+	assets, err := g.DB.FindByScope(fqdns, qtime)
 	if err != nil {
 		return res
 	}
@@ -226,7 +232,12 @@ func EventNames(ctx context.Context, g *netmap.Graph, domains []string, since ti
 		fqdns = append(fqdns, domain.FQDN{Name: d})
 	}
 
-	assets, err := g.DB.FindByScope(fqdns, since)
+	qtime := time.Time{}
+	if !since.IsZero() {
+		qtime = since.UTC()
+	}
+
+	assets, err := g.DB.FindByScope(fqdns, qtime)
 	if err != nil {
 		return res
 	}
